From 2f07f0dece96c822aa1b877c13a839338317547d Mon Sep 17 00:00:00 2001
From: Lynx <141365347+iLynxcat@users.noreply.github.com>
Date: Mon, 7 Oct 2024 16:19:14 -0700
Subject: [PATCH] update release status show in onboarding to beta
---
apps/storybook/package.json | 2 +-
apps/web/cypress/e2e/1-onboarding.spec.cy.ts | 6 +++---
apps/web/cypress/fixtures/routes.ts | 2 +-
interface/app/onboarding/index.tsx | 8 ++++----
.../onboarding/{alpha.tsx => prerelease.tsx} | 10 +++++-----
interface/locales/ar/common.json | 4 ++--
interface/locales/be/common.json | 4 ++--
interface/locales/cs/common.json | 4 ++--
interface/locales/de/common.json | 4 ++--
interface/locales/en/common.json | 4 ++--
interface/locales/es/common.json | 4 ++--
interface/locales/fr/common.json | 4 ++--
interface/locales/it/common.json | 4 ++--
interface/locales/ja/common.json | 4 ++--
interface/locales/nl/common.json | 4 ++--
interface/locales/ru/common.json | 4 ++--
interface/locales/tr/common.json | 4 ++--
interface/locales/zh-CN/common.json | 4 ++--
interface/locales/zh-TW/common.json | 4 ++--
interface/package.json | 2 +-
pnpm-lock.yaml | Bin 1062234 -> 1083129 bytes
21 files changed, 43 insertions(+), 43 deletions(-)
rename interface/app/onboarding/{alpha.tsx => prerelease.tsx} (84%)
diff --git a/apps/storybook/package.json b/apps/storybook/package.json
index 75e6621af..0f5786227 100644
--- a/apps/storybook/package.json
+++ b/apps/storybook/package.json
@@ -28,7 +28,7 @@
"prop-types": "^15.8.1",
"rollup-plugin-node-builtins": "^2.1.2",
"storybook": "^8.0.1",
- "tailwindcss": "^3.4.1",
+ "tailwindcss": "^3.4.10",
"typescript": "^5.6.2",
"vite": "^5.2.0"
}
diff --git a/apps/web/cypress/fixtures/routes.ts b/apps/web/cypress/fixtures/routes.ts
index 0e78b83ab..be515eeb2 100644
--- a/apps/web/cypress/fixtures/routes.ts
+++ b/apps/web/cypress/fixtures/routes.ts
@@ -1,4 +1,4 @@
-export const onboardingRegex = /\/onboarding\/alpha$/;
+export const onboardingRegex = /\/onboarding\/prerelease$/;
export const libraryRegex = /\/[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\//;
export const newLibraryRegex = /\/onboarding\/new-library$/;
export const onboardingLocationRegex = /\/onboarding\/locations$/;
diff --git a/interface/app/onboarding/index.tsx b/interface/app/onboarding/index.tsx
index 5338953b8..f57a4e379 100644
--- a/interface/app/onboarding/index.tsx
+++ b/interface/app/onboarding/index.tsx
@@ -1,13 +1,13 @@
import { Navigate, redirect, RouteObject } from 'react-router';
import { onboardingStore } from '@sd/client';
-import Alpha from './alpha';
import { useOnboardingContext } from './context';
import CreatingLibrary from './creating-library';
import { FullDisk } from './full-disk';
import { JoinLibrary } from './join-library';
import Locations from './locations';
import NewLibrary from './new-library';
+import PreRelease from './prerelease';
import Privacy from './privacy';
const Index = () => {
@@ -16,7 +16,7 @@ const Index = () => {
if (onboardingStore.lastActiveScreen && !ctx.library)
return ;
- return ;
+ return ;
};
export default [
@@ -28,11 +28,11 @@ export default [
replace: true
});
- return redirect(`/onboarding/alpha`, { replace: true });
+ return redirect(`/onboarding/prerelease`, { replace: true });
},
element:
},
- { path: 'alpha', Component: Alpha },
+ { Component: PreRelease, path: 'prerelease' },
// {
// element: ,
// path: 'login'
diff --git a/interface/app/onboarding/alpha.tsx b/interface/app/onboarding/prerelease.tsx
similarity index 84%
rename from interface/app/onboarding/alpha.tsx
rename to interface/app/onboarding/prerelease.tsx
index c8d47394a..156d6e5a5 100644
--- a/interface/app/onboarding/alpha.tsx
+++ b/interface/app/onboarding/prerelease.tsx
@@ -6,7 +6,7 @@ import { usePlatform } from '~/util/Platform';
import { OnboardingContainer } from './components';
-export default function OnboardingAlpha() {
+export default function OnboardingPreRelease() {
const platform = usePlatform();
const isDark = useIsDark();
@@ -17,17 +17,17 @@ export default function OnboardingAlpha() {
-

+
Spacedrive
-
{t('alpha_release_title')}
+
{t('prelease_title')}
- {t('alpha_release_description')}
+ {t('prerelease_description')}
diff --git a/apps/web/cypress/e2e/1-onboarding.spec.cy.ts b/apps/web/cypress/e2e/1-onboarding.spec.cy.ts
index 8066ba81e..2247a6e0f 100644
--- a/apps/web/cypress/e2e/1-onboarding.spec.cy.ts
+++ b/apps/web/cypress/e2e/1-onboarding.spec.cy.ts
@@ -10,7 +10,7 @@ import {
describe('Onboarding', () => {
// TODO: Create debug flag to bypass auto language detection
- it('Alpha onboarding', () => {
+ it('Pre-release onboarding', () => {
cy.visit('/', {
onBeforeLoad(win) {
cy.stub(win, 'open').as('winOpen');
@@ -34,8 +34,8 @@ describe('Onboarding', () => {
.and('have.prop', 'naturalWidth')
.should('be.greaterThan', 0);
- // Check we are in the alpha release screen
- cy.get('h1').should('contain', 'Alpha Release');
+ // Check we are in the beta release screen
+ cy.get('h1').should('contain', 'Beta Release');
// Check Join Discord button exists and point to a valid discord invite
cy.get('button').contains('Join Discord').click();